@@ -19,6 +19,42 @@ p2   <- pNBII(y2, mu = exp(eta2), sigma = sqrt(sigma2))
 
 }
 
+
+
+if( margin2 %in% c("DGP") ){
+
+mu2    <- c(eta2)
+sigma2 <- c(sigma2)
+
+     
+pdf2FUNC <- function(y2, mu2, sigma2) suppressWarnings(   (1 + mu2*y2/sqrt(sigma2))^(-1/mu2) - (1 + mu2*(1+y2)/sqrt(sigma2))^(-1/mu2)    )
+pdf2     <-   as.numeric( pdf2FUNC(y2, mu2, sigma2) )  
+
+if(robust == FALSE) p2  <- suppressWarnings(     rowSums( matrix(as.numeric( pdf2FUNC(y2m, mu2, sigma2)),dim(y2m)[1],dim(y2m)[2]), na.rm = TRUE )      )
+
+
+indx1 <- as.numeric( ((1 + mu2*y2/sqrt(sigma2))     > 0) == FALSE ) 
+indx2 <- as.numeric( ((1 + mu2*(y2+1)/sqrt(sigma2)) > 0) == FALSE )
+indx  <- rowSums(cbind(indx1, indx2))
+
+
+
+pdf2 <- ifelse( indx == 0, pdf2, 0)                 #
+if(robust == FALSE) p2 <- ifelse( indx == 0, p2, 0) #
+
+
+
+}
+
+
+
+
+
+
+
+
+
+
 if(margin2 == "PIG"){
 
 pdf2 <- dPIG(y2, mu = exp(eta2), sigma = sqrt(sigma2))  
@@ -92,10 +128,10 @@ y2  <- mpfr( y2, prec)
 } 
 
 
-pdf2FUNC <- function(y2, mu2) mu2^y2/(exp(mu2)-1)*1/factorial(y2)  
-pdf2     <- as.numeric( pdf2FUNC(y2, mu2) ) 
+pdf2FUNC2 <- function(y2, mu2) mu2^y2/(exp(mu2)-1)*1/factorial(y2)  
+pdf2     <- as.numeric( pdf2FUNC2(y2, mu2) ) 
 
-if(robust == FALSE) p2  <- rowSums( matrix(as.numeric( pdf2FUNC(y2m, mu2)),dim(y2m)[1],dim(y2m)[2]), na.rm = TRUE ) 
+if(robust == FALSE) p2  <- rowSums( matrix(as.numeric( pdf2FUNC2(y2m, mu2)),dim(y2m)[1],dim(y2m)[2]), na.rm = TRUE ) 
 
 
 
