@@ -10,10 +10,10 @@ yst.aver <- mean(x$y2)
 margin   <- x$margins[2]
 
 
-if(margin %in% c("PO","ZTP","NBI","NBII","NBIa","NBIIa","PIG","probit","logit","cloglog") ) stop("Check next release for the tested versions of these develoments.")
+#if(margin %in% c("PO","ZTP","NBI","NBII","NBIa","NBIIa","PIG","probit","logit","cloglog","DGP") ) stop("Check next release for the tested versions of these develoments.")
 
 
-if(margin %in% c("LN","WEI","iG","GA","GAi","DAGUM","SM","FISK") ) {yst.aver <- log(yst.aver); if(yst.aver == "-Inf") yst.aver <- log(1e-14) } 
+if(margin %in% c("LN","WEI","iG","GA","GAi","DAGUM","SM","FISK","GP") ) {yst.aver <- log(yst.aver); if(yst.aver == "-Inf") yst.aver <- log(1e-14) } 
 if(margin %in% c("BE") )                                           {yst.aver <- qlogis(mm(yst.aver)) }
 
 
@@ -110,7 +110,7 @@ BivD   <- out.beta$BivD
 y2 <- y2.st 
 
 
-if(margin %in% c("LN","WEI","iG","GA","GAi","DAGUM","SM","FISK") ) y2 <- esp.tr(y2.st, "LN")$vrb 
+if(margin %in% c("LN","WEI","iG","GA","GAi","DAGUM","SM","FISK","GP") ) y2 <- esp.tr(y2.st, "LN")$vrb 
 if(margin %in% c("BE") )                                           y2 <- esp.tr(y2.st, "BE")$vrb
 
 ppdf <- distrHsAT(y2, eta2, sigma2, nu, margin)
@@ -177,8 +177,23 @@ if( margin == "ZTP"){
 }
 
 
+if( margin == "DGDP"){
+
+mu2    <- c(exp(eta2))
+sigma2 <- c(sigma2)
+y2m <- seq(1, y2)                 
+
+     
+  pdf2FUNC2 <- function(y2, mu2, sigma2) (1 + sqrt(sigma2)*y2/mu2)^(-1/sqrt(sigma2)) - (1 + sqrt(sigma2)*(1+y2)/mu2)^(-1/sqrt(sigma2))  
+
+  p2  <- sum( as.numeric( pdf2FUNC2(y2m, mu2, sigma2) )  ) 
+
+
+}
+
+
 ppd <- distrHsATDiscr(y2, eta2, sigma2, nu, margin, y2m = NULL, robust = FALSE) 
-if( margin == "ZTP") ppd$p2 <- p2
+if( margin %in% c("ZTP","DGP")) ppd$p2 <- p2
 
 # test if it works for p2 when margin is ZTP
 
@@ -268,7 +283,7 @@ repeat{ #
    y2.imp[j] <- y2.st <- out.beta$y2 
    
 
-   if(margin %in% c("LN","WEI","iG","GA","GAi","DAGUM","SM","FISK") ) {y2.st <- log(y2.imp[j]); if(y2.st == "-Inf") y2.st <- log(1e-14)} 
+   if(margin %in% c("LN","WEI","iG","GA","GAi","DAGUM","SM","FISK","GP") ) {y2.st <- log(y2.imp[j]); if(y2.st == "-Inf") y2.st <- log(1e-14)} 
    if(margin %in% c("BE") )                                           {y2.st <- qlogis(mm(y2.imp[j]))}
  
 
@@ -281,7 +296,7 @@ if( margin %in% c("probit","logit","cloglog") ){
                                                 } 
  
 
-if( margin %in% c("PO","ZTP","NBI","NBII","NBIa","NBIIa","PIG") ){
+if( margin %in% c("PO","ZTP","NBI","NBII","NBIa","NBIIa","PIG","DGP") ){
    
    
    test.oD <- NA
@@ -298,7 +313,7 @@ if( margin %in% c("PO","ZTP","NBI","NBII","NBIa","NBIIa","PIG") ){
 
 
 
-if(!(margin %in% c("PO","ZTP","NBI","NBII","NBIa","NBIIa","PIG","probit","logit","cloglog")) ){
+if(!(margin %in% c("PO","ZTP","NBI","NBII","NBIa","NBIIa","PIG","probit","logit","cloglog","DGP")) ){
    
    f.g      <- obj.grad.hess(y2.st, out.beta)$value
    M.value  <- try(trust(obj.grad.hess, parinit = yst.aver, rinit = 1, rmax = 100, minimize = F, out.beta = out.beta)$value); if ('try-error' %in% class(M.value)) next
